@@ -19,8 +19,11 @@ import sys
 import tempfile
 import unittest
 
+import six
+
 from genshi.compat import BytesIO, StringIO
 from genshi.core import Markup
+from genshi.filters.i18n import Translator
 from genshi.input import XML
 from genshi.template.base import BadDirectiveError, TemplateSyntaxError
 from genshi.template.loader import TemplateLoader, TemplateNotFound
@@ -190,21 +193,21 @@ class MarkupTemplateTestCase(unittest.TestCase):
         </div>""", str(tmpl.generate()))
 
     def test_latin1_encoded_with_xmldecl(self):
-        tmpl = MarkupTemplate("""<?xml version="1.0" encoding="iso-8859-1" ?>
+        tmpl = MarkupTemplate(u"""<?xml version="1.0" encoding="iso-8859-1" ?>
         <div xmlns:py="http://genshi.edgewall.org/">
           \xf6
         </div>""".encode('iso-8859-1'), encoding='iso-8859-1')
-        self.assertEqual("""<?xml version="1.0" encoding="iso-8859-1"?>\n<div>
+        self.assertEqual(u"""<?xml version="1.0" encoding="iso-8859-1"?>\n<div>
           \xf6
-        </div>""", str(tmpl.generate()))
+        </div>""", six.text_type(tmpl.generate()))
 
     def test_latin1_encoded_explicit_encoding(self):
-        tmpl = MarkupTemplate("""<div xmlns:py="http://genshi.edgewall.org/">
+        tmpl = MarkupTemplate(u"""<div xmlns:py="http://genshi.edgewall.org/">
           \xf6
         </div>""".encode('iso-8859-1'), encoding='iso-8859-1')
-        self.assertEqual("""<div>
+        self.assertEqual(u"""<div>
           \xf6
-        </div>""", str(tmpl.generate()))
+        </div>""", six.text_type(tmpl.generate()))
 
     def test_exec_with_trailing_space(self):
         """
@@ -782,11 +785,24 @@ class MarkupTemplateTestCase(unittest.TestCase):
           </lines>
         </rhyme>""", tmpl.generate().render(encoding=None)) 
 
+    def test_directive_single_line_with_translator(self):
+        tmpl = MarkupTemplate("""<div xmlns:py="http://genshi.edgewall.org/">
+            <py:for each="i in range(2)"><py:for each="j in range(1)">
+                <span py:content="i + j"></span>
+            </py:for></py:for>
+        </div>""")
+        translator = Translator(lambda s: s)
+        tmpl.add_directives(Translator.NAMESPACE, translator)
+        self.assertEqual("""<div>
+                <span>0</span>
+                <span>1</span>
+        </div>""", str(tmpl.generate()))
+
 
 def suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite(MarkupTemplate.__module__))
-    suite.addTest(unittest.makeSuite(MarkupTemplateTestCase, 'test'))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(MarkupTemplateTestCase))
     return suite
 
 if __name__ == '__main__':
